:notoc:

===============
Troubleshooting
===============

These articles focus on a specific problem and aim at offering potential solutions
for that problem.

If you need help please contact us using one of these options.


.. panels::
   :card: border-0
   :container: container-lg pb-3
   :column: col-md-4 col-md-4 col-md-4 p-2
   :body: text-center border-0
   :header: text-center border-0 h4 bg-white
   :footer: border-0 bg-white

   Community Slack
   ^^^^^^^^^^^^^^^

   .. link-button:: https://join.slack.com/t/coiled-users/shared_invite/zt-hx1fnr7k-In~Q8ui3XkQfvQon0yN5WQ
      :type: url
      :text: Ask a question
      :classes: btn-outline-primary btn-block stretched-link

   ---

   GitHub Issues
   ^^^^^^^^^^^^^

   .. link-button:: https://github.com/coiled/feedback/issues/new
      :type: url
      :text: Create an issue
      :classes: btn-outline-primary btn-block stretched-link

   ---

   Email
   ^^^^^^^^^^^^^^^

   .. link-button:: mailto:support@coiled.io
      :type: url
      :text: Send an email
      :classes: btn-outline-primary btn-block stretched-link


Articles in this category
^^^^^^^^^^^^^^^^^^^^^^^^^

.. toctree::
    :maxdepth: 1

    timeout_error
    killedworker_exception